@@ -5,8 +5,9 @@
  * Copyright (C) 2006-2007 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1927,7 +1928,7 @@ xlsx_write_sheet (XLSXWriteState *state, GsfOutfile *dir, GsfOutfile *wb_part, u
 	GnmStyle **col_styles;
 
 	state->sheet = workbook_sheet_by_index (state->base.wb, i);
-	col_styles = g_new (GnmStyle*, XLSX_MAX_COLS);
+	col_styles = sheet_style_most_common (state->sheet, TRUE);
 	excel_sheet_extent (state->sheet, &extent, col_styles,
 			    XLSX_MAX_COLS, XLSX_MAX_ROWS, state->io_context);
 	cell_extent = sheet_get_cells_extent (state->sheet);
