@@ -5,9 +5,10 @@
  * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
  * Copyright (C) 2006-2009 Morten Welinder (terra@gnome.org)
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as published
- * by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1575,8 +1576,8 @@ iterate :
 			gboolean was_string = had_value && (VALUE_IS_STRING (cell->value) || VALUE_IS_ERROR (cell->value));
 			gboolean is_string = VALUE_IS_STRING (v) || VALUE_IS_ERROR (v);
 
-			if ((was_string || is_string) && cell->row_info)
-				cell->row_info->needs_respan = TRUE;
+			if ((was_string || is_string))
+				sheet_cell_queue_respan (cell);
 
 			if (had_value)
 				value_release (cell->value);
