@@ -6,8 +6,9 @@
  * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -229,13 +230,14 @@ dhl_set_target_email (HyperlinkState *state, const char* const target)
 
 	subject = strstr (cursor, "?subject=");
 	if (subject) {
-		guitext = go_url_decode (subject + strlen ("?subject="));
+		guitext = g_uri_unescape_string (subject + strlen ("?subject="),
+						 NULL);
 		gtk_entry_set_text (GTK_ENTRY (w2), guitext);
 		*subject = '\0';
 		g_free (guitext);
 	}
 
-	guitext = go_url_decode (cursor);
+	guitext = g_uri_unescape_string (cursor, NULL);
 
 	gtk_entry_set_text (GTK_ENTRY (w), guitext);
 
