@@ -322,7 +322,7 @@ search_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 	is_regexp = (i == 1);
 	is_number = (i == 2);
 
-	text = g_utf8_normalize (gtk_entry_get_text (dd->gentry), -1, G_NORMALIZE_DEFAULT);
+	text = gnm_search_normalize (gtk_entry_get_text (dd->gentry));
 
 	sr = g_object_new (GNM_SEARCH_REPLACE_TYPE,
 			   "sheet", wb_control_cur_sheet (wbc),
@@ -508,7 +508,11 @@ dialog_search (WBCGtk *wbcg)
 		gtk_notebook_page_num (dd->notebook,
 				       go_gtk_builder_get_widget (gui, "matches_tab"));
 
+#ifdef USE_GURU
 	dd->rangetext = gnm_expr_entry_new (wbcg, TRUE);
+#else
+	dd->rangetext = gnm_expr_entry_new (wbcg, FALSE);
+#endif
 	gnm_expr_entry_set_flags (dd->rangetext, 0, GNM_EE_MASK);
 	table = GTK_TABLE (gtk_builder_get_object (gui, "page1-table"));
 	gtk_table_attach (table, GTK_WIDGET (dd->rangetext),
