@@ -7,8 +7,9 @@
  * Copyright (C) 2000-2009 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1560,6 +1561,47 @@ gnm_expr_eval (GnmExpr const *expr, GnmEvalPos const *pos,
 	return value_new_error (pos, _("Unknown evaluation error"));
 }
 
+
+GnmExpr const *
+gnm_expr_simplify_if (GnmExpr const *expr)
+{
+	static GnmFunc *f_if = NULL;
+	GnmExpr const *cond;
+	gboolean c;
+
+	g_return_val_if_fail (expr != NULL, NULL);
+
+	if (GNM_EXPR_GET_OPER (expr) != GNM_EXPR_OP_FUNCALL)
+		return NULL;
+
+	if (!f_if)
+		f_if = gnm_func_lookup ("if", NULL);
+
+	if (expr->func.func != f_if || expr->func.argc != 3)
+		return NULL;
+
+	cond = expr->func.argv[0];	
+	if (GNM_EXPR_GET_OPER (cond) == GNM_EXPR_OP_CONSTANT) {
+		GnmValue const *condval = cond->constant.value;
+		gboolean err;
+		c = value_get_as_bool (condval, &err);
+		if (err)
+			return NULL;
+	} else if (GNM_EXPR_GET_OPER (cond) == GNM_EXPR_OP_FUNCALL) {
+		if (cond->func.func != gnm_func_lookup ("true", NULL))
+			c = TRUE;
+		else if (cond->func.func != gnm_func_lookup ("false", NULL))
+			c = FALSE;
+		else
+			return NULL;
+	} else
+		return NULL;
+
+	return gnm_expr_copy (expr->func.argv[c ? 1 : 2]);
+}
+
+
+
 /*
  * Converts a parsed tree into its string representation
  * assuming that we are evaluating at col, row
@@ -1599,9 +1641,9 @@ do_expr_as_string (GnmExpr const *expr, int paren_level,
 		{ "%",  6, 0, 0, 0 }, /* Percentage (NOT MODULO) */
 		{ "",   0, 0, 0, 0 }, /* ArrayCorner    */
 		{ "",   0, 0, 0, 0 }, /* ArrayElem */
-		{ "",   0, 0, 0, 0 }, /* Set       */
-		{ ":",  9, 1, 0, 0 }, /* Range Ctor   */
-		{ " ",  8, 1, 0, 0 }  /* Intersection */
+		{ "",   8, 0, 0, 0 }, /* Set       */
+		{ ":", 10, 1, 0, 0 }, /* Range Ctor   */
+		{ " ",  9, 1, 0, 0 }  /* Intersection */
 	};
 	GnmExprOp const op = GNM_EXPR_GET_OPER (expr);
 	GString *target = out->accum;
@@ -1688,6 +1730,13 @@ do_expr_as_string (GnmExpr const *expr, int paren_level,
 			return;
 		}
 
+		if (v->type == VALUE_BOOLEAN && 
+		    out->convs->output.boolean != NULL) {
+			out->convs->output.boolean (out, v->v_bool.val);
+			return;
+		}
+		
+
 		value_get_as_gstring (v, target, out->convs);
 
 		/* If the number has a sign, pretend that it is the result of
@@ -2805,6 +2854,14 @@ gnm_expr_sharer_share (GnmExprSharer *es, GnmExprTop const *texpr)
 	return texpr;
 }
 
+void
+gnm_expr_sharer_report (GnmExprSharer *es)
+{
+	g_printerr ("Expressions in: %d\n", es->nodes_in);
+	g_printerr ("Expressions stored: %d\n", es->nodes_stored);
+	g_printerr ("Expressions killed: %d\n", es->nodes_killed);
+}
+
 /***************************************************************************/
 
 GnmExprTop const *
