@@ -24,7 +24,6 @@
 #include "libgnumeric.h"
 #include "wbc-gtk.h"
 #include "widgets/gnumeric-expr-entry.h"
-#include "gnm-rsm.h"
 
 #include <goffice/goffice.h>
 #include <gtk/gtk.h>
@@ -426,7 +425,7 @@ gnm_gui_group_value (gpointer gui, char const * const group[])
 }
 
 static void
-kill_popup_menu (GtkWidget *widget, GtkMenu *menu)
+kill_popup_menu (G_GNUC_UNUSED GtkWidget *widget, GtkMenu *menu)
 {
 	g_return_if_fail (menu != NULL);
 	g_return_if_fail (GTK_IS_MENU (menu));
@@ -477,6 +476,20 @@ gnumeric_tooltip_set_style (GtkWidget *widget)
 	}
 }
 
+GtkWidget *
+gnumeric_create_tooltip_text_view_widget (void)
+{
+	GtkWidget *label, *frame;
+
+	frame = gtk_frame_new (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
+	label = gtk_text_view_new ();
+
+	gtk_container_add (GTK_CONTAINER (frame), label);
+
+	return label;
+}
+
 GtkWidget *
 gnumeric_create_tooltip_widget (void)
 {
@@ -492,9 +505,9 @@ gnumeric_create_tooltip_widget (void)
 }
 
 GtkWidget *
-gnumeric_create_tooltip (GtkWidget *ref_widget)
+gnumeric_convert_to_tooltip (GtkWidget *ref_widget, GtkWidget *label)
 {
-	GtkWidget *tip, *label, *frame;
+	GtkWidget *tip, *frame;
 
 	tip = gtk_window_new (GTK_WINDOW_POPUP);
 	gtk_window_set_type_hint (GTK_WINDOW (tip),
@@ -504,7 +517,6 @@ gnumeric_create_tooltip (GtkWidget *ref_widget)
 	gtk_window_set_screen (GTK_WINDOW (tip), gtk_widget_get_screen (ref_widget));
 	gtk_widget_set_name (tip, "gnumeric-tooltip");
 
-	label = gnumeric_create_tooltip_widget ();
 	frame = gtk_widget_get_toplevel (label);
 
 	gtk_container_add (GTK_CONTAINER (tip), frame);
@@ -515,6 +527,12 @@ gnumeric_create_tooltip (GtkWidget *ref_widget)
 	return label;
 }
 
+GtkWidget *
+gnumeric_create_tooltip (GtkWidget *ref_widget)
+{
+	return gnumeric_convert_to_tooltip (ref_widget, gnumeric_create_tooltip_widget ());
+}
+
 void
 gnumeric_position_tooltip (GtkWidget *tip, int px, int py, gboolean horizontal)
 {
@@ -949,8 +967,7 @@ gnm_load_pango_attributes_into_buffer (PangoAttrList  *markup, GtkTextBuffer *bu
 }
 
 #define gnmstoretexttagattrinpangoint(nameset, name, gnm_pango_attr_new)  \
-	g_object_get (G_OBJECT (tag), nameset, &is_set, NULL);            \
-	if (is_set) {                                                     \
+	if (gnm_object_get_bool (tag, nameset)) {			  \
 		int value;                                                \
 		g_object_get (G_OBJECT (tag), name, &value, NULL);        \
 		attr =  gnm_pango_attr_new (value);                       \
@@ -965,22 +982,36 @@ gnm_store_text_tag_attr_in_pango (PangoAttrList *list, GtkTextTag *tag, GtkTextI
 {
 	GtkTextIter end = *start;
 	gint x, y;
-	gboolean is_set;
 	PangoAttribute * attr;
 
 	gtk_text_iter_forward_to_tag_toggle (&end, tag);
 	x = g_utf8_offset_to_pointer (text, gtk_text_iter_get_offset (start)) - text;
 	y = g_utf8_offset_to_pointer (text, gtk_text_iter_get_offset (&end)) - text;
 
-	g_object_get (G_OBJECT (tag), "foreground-set", &is_set, NULL);
-	if (is_set) {
-		GdkColor* color;
+	if (gnm_object_get_bool (tag, "foreground-set")) {
+#if GTK_MAJOR_VERSION > 3 || GTK_MINOR_VERSION >= 2
+		GdkRGBA *color = NULL;
+		g_object_get (G_OBJECT (tag), "foreground-rgba", &color, NULL);
+#else
+		GdkColor *color = NULL;
 		g_object_get (G_OBJECT (tag), "foreground-gdk", &color, NULL);
-		attr =  pango_attr_foreground_new (color->red, color->green, color->blue);
-		attr->start_index = x;
-		attr->end_index = y;
-		pango_attr_list_change (list, attr);
-		gdk_color_free (color);
+#endif
+		if (color) {
+#if GTK_MAJOR_VERSION > 3 || GTK_MINOR_VERSION >= 2
+			/* dividing 0 to 1 into 65536 equal length intervals */
+			attr =  pango_attr_foreground_new
+				((int)(CLAMP (color->red * 65536, 0., 65535.)),
+				 (int)(CLAMP (color->green * 65536, 0., 65535.)),
+				 (int)(CLAMP (color->blue * 65536, 0., 65535.)));
+			gdk_rgba_free (color);
+#else
+			attr =  pango_attr_foreground_new (color->red, color->green, color->blue);
+			gdk_color_free (color);
+#endif
+			attr->start_index = x;
+			attr->end_index = y;
+			pango_attr_list_change (list, attr);
+		}
 	}
 
 	gnmstoretexttagattrinpangoint ("style-set", "style", pango_attr_style_new)
