@@ -1,13 +1,12 @@
-/* vim: set sw=8: */
-
 /*
  * sheet-style.c: storage mechanism for styles and eventually cells.
  *
  * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as published
- * by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,6 +18,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
+
 #include <gnumeric-config.h>
 #include "sheet-style.h"
 #include "gnm-style-impl.h"
@@ -37,9 +37,7 @@
 #include <string.h>
 #include <math.h>
 
-#ifndef USE_TILE_POOLS
-#define USE_TILE_POOLS 1
-#endif
+#define USE_TILE_POOLS 0
 
 typedef union _CellTile CellTile;
 struct _GnmSheetStyleData {
@@ -287,14 +285,27 @@ union _CellTile {
 	CellTilePtrMatrix	ptr_matrix;
 };
 
+static int active_sheet_count;
 #if USE_TILE_POOLS
-static int tile_pool_users;
 static GOMemChunk *tile_pools[5];
-#define CHUNK_ALLOC(T,p) ((T*)go_mem_chunk_alloc (p))
-#define CHUNK_FREE(p,v) go_mem_chunk_free ((p), (v))
+#define CHUNK_ALLOC(T,ctt) ((T*)go_mem_chunk_alloc (tile_pools[(ctt)]))
+#define CHUNK_FREE(ctt,v) go_mem_chunk_free (tile_pools[(ctt)], (v))
 #else
-#define CHUNK_ALLOC(T,c) g_new (T,1)
-#define CHUNK_FREE(p,v) g_free ((v))
+static const size_t tile_type_sizeof[5] = {
+	sizeof (CellTileStyleSimple),
+	sizeof (CellTileStyleCol),
+	sizeof (CellTileStyleRow),
+	sizeof (CellTileStyleMatrix),
+	sizeof (CellTilePtrMatrix)
+};
+static int tile_allocations = 0;
+#if 1
+#define CHUNK_ALLOC(T,ctt) (tile_allocations++, (T*)g_slice_alloc (tile_type_sizeof[(ctt)]))
+#define CHUNK_FREE(ctt,v) (tile_allocations--, g_slice_free1 (tile_type_sizeof[(ctt)], (v)))
+#else
+#define CHUNK_ALLOC(T,ctt) (tile_allocations++, (T*)g_malloc (tile_type_sizeof[(ctt)]))
+#define CHUNK_FREE(ctt,v) (tile_allocations--, g_free ((v)))
+#endif
 #endif
 
 
@@ -323,31 +334,13 @@ cell_tile_dtor (CellTile *tile)
 	}
 
 	*((CellTileType *)&(tile->type)) = TILE_UNDEFINED; /* poison it */
-	CHUNK_FREE (tile_pools[t], tile);
+	CHUNK_FREE (t, tile);
 }
 
 static CellTile *
 cell_tile_style_new (GnmStyle *style, CellTileType t)
 {
-	CellTile *res;
-
-#if USE_TILE_POOLS
-	res = CHUNK_ALLOC (CellTile, tile_pools[t]);
-#else
-	switch (t) {
-	case TILE_SIMPLE : res = (CellTile *)g_new (CellTileStyleSimple, 1);
-			   break;
-	case TILE_COL :	   res = (CellTile *)g_new (CellTileStyleCol, 1);
-			   break;
-	case TILE_ROW :	   res = (CellTile *)g_new (CellTileStyleRow, 1);
-			   break;
-	case TILE_MATRIX : res = (CellTile *)g_new (CellTileStyleMatrix, 1);
-			   break;
-	default : g_return_val_if_fail (FALSE, NULL);
-		return NULL;
-	}
-#endif
-
+	CellTile *res = CHUNK_ALLOC (CellTile, t);
 	*((CellTileType *)&(res->type)) = t;
 
 	if (style != NULL) {
@@ -369,7 +362,7 @@ cell_tile_ptr_matrix_new (CellTile *t)
 	g_return_val_if_fail (TILE_SIMPLE <= t->type &&
 			      TILE_MATRIX >= t->type, NULL);
 
-	res = CHUNK_ALLOC (CellTilePtrMatrix, tile_pools[TILE_PTR_MATRIX]);
+	res = CHUNK_ALLOC (CellTilePtrMatrix, TILE_PTR_MATRIX);
 	*((CellTileType *)&(res->type)) = TILE_PTR_MATRIX;
 
 	/* TODO :
@@ -514,8 +507,8 @@ sheet_style_init_size (Sheet *sheet, int cols, int rows)
 	sheet->max_height = tile_heights[sheet->tile_top_level];
 	sheet->max_width = tile_widths[sheet->tile_top_level];
 
+	if (active_sheet_count++ == 0) {
 #if USE_TILE_POOLS
-	if (tile_pool_users++ == 0) {
 		tile_pools[TILE_SIMPLE] =
 			go_mem_chunk_new ("simple tile pool",
 					   sizeof (CellTileStyleSimple),
@@ -537,8 +530,8 @@ sheet_style_init_size (Sheet *sheet, int cols, int rows)
 		/* If this fails one day, just make two pools.  */
 		g_assert (sizeof (CellTileStyleMatrix) == sizeof (CellTilePtrMatrix));
 		tile_pools[TILE_PTR_MATRIX] = tile_pools[TILE_MATRIX];
-	}
 #endif
+	}
 
 	sheet->style_data = g_new (GnmSheetStyleData, 1);
 	sheet->style_data->style_hash =
@@ -654,8 +647,8 @@ sheet_style_shutdown (Sheet *sheet)
 	g_free (sheet->style_data);
 	sheet->style_data = NULL;
 
+	if (--active_sheet_count == 0) {
 #if USE_TILE_POOLS
-	if (--tile_pool_users == 0) {
 		go_mem_chunk_foreach_leak (tile_pools[TILE_SIMPLE],
 					    cb_tile_pool_leak, NULL);
 		go_mem_chunk_destroy (tile_pools[TILE_SIMPLE], FALSE);
@@ -679,8 +672,11 @@ sheet_style_shutdown (Sheet *sheet)
 		/* If this fails one day, just make two pools.  */
 		g_assert (sizeof (CellTileStyleMatrix) == sizeof (CellTilePtrMatrix));
 		tile_pools[TILE_PTR_MATRIX] = NULL;
-	}
+#else
+		if (tile_allocations)
+			g_printerr ("Leaking %d style tiles.\n", tile_allocations);
 #endif
+	}
 }
 
 /**
@@ -975,6 +971,11 @@ try_optimize:
 	}
 }
 
+/* Handler for foreach_tile.
+ *
+ * "width" and "height" refer to tile size which may extend beyond
+ * the range supplied to foreach_tile and even beyond the sheet.
+ */
 typedef void (*ForeachTileFunc) (GnmStyle *style,
 				 int corner_col, int corner_row, int width, int height,
 				 GnmRange const *apply_to, gpointer user);
@@ -1924,104 +1925,207 @@ sheet_style_insert_colrow (GnmExprRelocateInfo const *rinfo)
 	}
 }
 
-static void
-cb_visible_content (GnmStyle *style,
-		    int corner_col, int corner_row, int width, int height,
-		    GnmRange const *apply_to, gpointer res)
-{
-	*((gboolean *)res) |= gnm_style_visible_in_blank (style);
-}
-
-/**
- * sheet_style_has_visible_content :
- *
- * @sheet :
- * @r     :
- *
- * Are any of the styles in the target region visible in a blank cell.  The
- * implementation is simplistic.  We should really ignore borders at the
- * edges IF they have been seen before.
- */
-gboolean
-sheet_style_has_visible_content (Sheet const *sheet, GnmRange *src)
-{
-	gboolean res = FALSE;
-	foreach_tile (sheet->style_data->styles,
-		      sheet->tile_top_level, 0, 0, src,
-		      cb_visible_content, &res);
-	return res;
-}
-
-typedef struct {
-	GnmRange *res;
-	GnmStyle **most_common_in_cols;
-} StyleExtentData;
-
 static void
 cb_style_extent (GnmStyle *style,
 		 int corner_col, int corner_row, int width, int height,
 		 GnmRange const *apply_to, gpointer user)
 {
-	StyleExtentData *data = user;
+	GnmRange *res = user;
 	if (gnm_style_visible_in_blank (style)) {
+		int tmp;
 
-		/* always check if the column is extended */
-		int tmp = corner_col+width-1;
-		int i = corner_col;
-		if (data->res->end.col < tmp)
-			data->res->end.col = tmp;
-		if (data->res->start.col > corner_col)
-			data->res->start.col = corner_col;
+		/* The given dimensions refer to the tile, not the area. */
+		width = MIN (width, apply_to->end.col - corner_col + 1);
+		height = MIN (height, apply_to->end.row - corner_row + 1);
+
+		tmp = corner_col+width-1;
+		if (res->end.col < tmp)
+			res->end.col = tmp;
+		if (res->start.col > corner_col)
+			res->start.col = corner_col;
 
-		/* only check the row if the style is not the most common in
-		 * all of the columns in the tile */
-		if (data->most_common_in_cols != NULL) {
-			for (; i <= tmp ; i++)
-				if (style != data->most_common_in_cols[i])
-					break;
-			if (i > tmp)
-				return;
-		}
 		tmp = corner_row+height-1;
-		if (data->res->end.row < tmp)
-			data->res->end.row = tmp;
-		if (data->res->start.row > corner_row)
-			data->res->start.row = corner_row;
+		if (res->end.row < tmp)
+			res->end.row = tmp;
+		if (res->start.row > corner_row)
+			res->start.row = corner_row;
 	}
 }
 
 /**
- * sheet_style_get_extent :
+ * sheet_style_get_extent:
  *
- * @sheet :
- * @r     :
- * most_common_in_cols : optionally NULL.
+ * @sheet: sheet to measure
+ * @res: starting range and resulting range
  *
  * A simple implementation that finds the smallest range containing all visible styles
- * and containing res. x If @most_common_in_cols is specified it finds the most common
- * style for each column (0..gnm_sheet_get_last_col (sheet)) and ignores that style in
- * boundary calculations.
+ * and containing @res.
  */
 void
-sheet_style_get_extent (Sheet const *sheet, GnmRange *res,
-			GnmStyle **most_common_in_cols)
+sheet_style_get_extent (Sheet const *sheet, GnmRange *res)
 {
-	StyleExtentData data;
 	GnmRange r;
 
-	if (most_common_in_cols != NULL) {
-		int i;
-		for (i = 0; i < gnm_sheet_get_max_cols (sheet); i++)
-			most_common_in_cols[i] = sheet_style_most_common_in_col (sheet, i);
-	}
-
-	/* This could easily be optimized */
-	data.res = res;
-	data.most_common_in_cols = most_common_in_cols;
 	range_init_full_sheet (&r, sheet);
 	foreach_tile (sheet->style_data->styles,
 		      sheet->tile_top_level, 0, 0, &r,
-		      cb_style_extent, &data);
+		      cb_style_extent, res);
+}
+
+struct cb_nondefault_extent {
+	GnmRange *res;
+	GnmStyle **col_defaults;
+};
+
+static void
+cb_nondefault_extent (GnmStyle *style,
+		      int corner_col, int corner_row, int width, int height,
+		      GnmRange const *apply_to, gpointer user_)
+{
+	struct cb_nondefault_extent *user = user_;
+	GnmRange *res = user->res;
+	int i;
+
+	for (i = 0; i < width; i++) {
+		int col = corner_col + i;
+		if (col >= apply_to->start.col &&
+		    col <= apply_to->end.col &&
+		    style != user->col_defaults[col]) {
+			int max_row = MIN (corner_row + height - 1,
+					   apply_to->end.row);
+			int min_row = MAX (corner_row, apply_to->start.row);
+
+			res->start.col = MIN (col, res->start.col);
+			res->start.row = MIN (min_row, res->start.row);
+
+			res->end.col = MAX (col, res->end.col);
+			res->end.row = MAX (max_row, res->end.row);
+		}
+	}
+}
+
+void
+sheet_style_get_nondefault_extent (Sheet const *sheet, GnmRange *extent,
+				   const GnmRange *src, GnmStyle **col_defaults)
+{
+	struct cb_nondefault_extent user;
+	user.res = extent;
+	user.col_defaults = col_defaults;
+	foreach_tile (sheet->style_data->styles,
+		      sheet->tile_top_level, 0, 0, src,
+		      cb_nondefault_extent, &user);
+}
+
+struct cb_is_default {
+	gboolean res;
+	GnmStyle **col_defaults;
+};
+
+static void
+cb_is_default (GnmStyle *style,
+	       int corner_col, int corner_row, int width, int height,
+	       GnmRange const *apply_to, gpointer user_)
+{
+	struct cb_is_default *user = user_;
+	int i;
+
+	/* The given "width" refers to the tile, not the area. */
+	width = MIN (width, apply_to->end.col - corner_col + 1);
+
+	for (i = 0; user->res && i < width; i++) {
+		if (style != user->col_defaults[corner_col + i])
+			user->res = FALSE;
+	}
+}
+
+gboolean
+sheet_style_is_default (Sheet const *sheet, const GnmRange *r, GnmStyle **col_defaults)
+{
+	struct cb_is_default user;
+
+	user.res = TRUE;
+	user.col_defaults = col_defaults;
+
+	foreach_tile (sheet->style_data->styles,
+		      sheet->tile_top_level, 0, 0, r,
+		      cb_is_default, &user);
+
+	return user.res;
+}
+
+
+struct cb_most_common {
+	GHashTable *h;
+	int l;
+	gboolean is_col;
+};
+
+static void
+cb_most_common (GnmStyle *style,
+		int corner_col, int corner_row, int width, int height,
+		GnmRange const *apply_to, gpointer user)
+{
+	struct cb_most_common *cmc = user;
+	int *counts = g_hash_table_lookup (cmc->h, style);
+	int i;
+	if (!counts) {
+		counts = g_new0 (int, cmc->l);
+		g_hash_table_insert (cmc->h, style, counts);
+	}
+
+	/* The given dimensions refer to the tile, not the area. */
+	width = MIN (width, apply_to->end.col - corner_col + 1);
+	height = MIN (height, apply_to->end.row - corner_row + 1);
+
+	if (cmc->is_col)
+		for (i = 0; i < width; i++)
+			counts[corner_col + i] += height;
+	else
+		for (i = 0; i < height; i++)
+			counts[corner_row + i] += width;
+}
+
+GnmStyle **
+sheet_style_most_common (Sheet const *sheet, gboolean is_col)
+{
+	GnmRange r;
+	struct cb_most_common cmc;
+	int *max;
+	GnmStyle **res;
+	GHashTableIter iter;
+	gpointer key, value;
+
+	g_return_val_if_fail (IS_SHEET (sheet), NULL);
+
+	range_init_full_sheet (&r, sheet);
+	cmc.h = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_free);
+	cmc.l = colrow_max (is_col, sheet);
+	cmc.is_col = is_col;
+	foreach_tile (sheet->style_data->styles,
+		      sheet->tile_top_level, 0, 0, &r,
+		      cb_most_common, &cmc);
+
+	max = g_new0 (int, cmc.l);
+	res = g_new0 (GnmStyle *, cmc.l);
+	g_hash_table_iter_init (&iter, cmc.h);
+	while (g_hash_table_iter_next (&iter, &key, &value)) {
+		int *counts = value;
+		GnmStyle *style = key;
+		int j;
+		for (j = 0; j < cmc.l; j++) {
+			/* FIXME: we really ought to break ties in a
+			   consistent way that does not depend on hash
+			   order.  */
+			if (counts[j] > max[j]) {
+				max[j] = counts[j];
+				res[j] = style;
+			}
+		}
+	}
+	g_hash_table_destroy (cmc.h);
+	g_free (max);
+
+	return res;
 }
 
 /****************************************************************************/
@@ -2447,68 +2551,6 @@ style_list_get_style (GnmStyleList const *list, int col, int row)
 	return NULL;
 }
 
-static void
-cb_accumulate_count (GnmStyle *style,
-		     int corner_col, int corner_row, int width, int height,
-		     GnmRange const *apply_to, gpointer accumulator)
-{
-	gpointer count;
-
-	count = g_hash_table_lookup (accumulator, style);
-	if (count == NULL) {
-		int *res = g_new (int, 1);
-		*res = height;
-		g_hash_table_insert (accumulator, style, res);
-	} else
-		*((int *)count) += height;
-}
-
-typedef struct
-{
-	GnmStyle *style;
-	int     count;
-} MostCommon;
-
-static void
-cb_find_max (gpointer key, gpointer value, gpointer user_data)
-{
-	MostCommon *mc = user_data;
-	int count = *((int *)value);
-	if (mc->style == NULL || mc->count < count) {
-		mc->style = key;
-		mc->count = count;
-	}
-
-	g_free (value);
-}
-
-/**
- * sheet_style_most_common_in_col :
- * @sheet :
- * @col :
- *
- * Find the most common style in a column.
- * The resulting style does not have its reference count bumped.
- */
-GnmStyle *
-sheet_style_most_common_in_col (Sheet const *sheet, int col)
-{
-	MostCommon  res;
-	GHashTable *accumulator;
-	GnmRange       r;
-
-	range_init_cols (&r, sheet, col, col);
-	accumulator = g_hash_table_new (gnm_style_hash, (GCompareFunc) gnm_style_equal);
-	foreach_tile (sheet->style_data->styles,
-		      sheet->tile_top_level, 0, 0, &r,
-		      cb_accumulate_count, accumulator);
-
-	res.style = NULL;
-	g_hash_table_foreach (accumulator, cb_find_max, &res);
-	g_hash_table_destroy (accumulator);
-	return res.style;
-}
-
 static void
 cb_find_link (GnmStyle *style,
 	      int corner_col, int corner_row, int width, int height,
