@@ -49,6 +49,7 @@
 #define UNICODE_ELLIPSIS "\xe2\x80\xa6"
 #define UNICODE_ELLIPSIS_VERT "\xe2\x8b\xae"
 #define UNICODE_ARROW_UP "\xe2\x87\xa7"
+#define UNICODE_CHECKMARK "\342\234\223"
 
 #warning We should replace these token names with the correct values
    enum yytokentype {
@@ -136,6 +137,7 @@ struct _GnmExprEntry {
 		gint             args;
 		gboolean         had_stuff;
 		gulong           handlerid;
+		guint            timerid;
 		gboolean         enabled;
 		gboolean         is_expr;
 		gboolean         completion_se_valid;
@@ -208,10 +210,11 @@ static inline void
 gee_force_abs_rel (GnmExprEntry *gee)
 {
 	Rangesel *rs = &gee->rangesel;
+	rs->is_valid = FALSE;
 	if ((gee->flags & GNM_EE_FORCE_ABS_REF))
 		rs->ref.a.col_relative = rs->ref.b.col_relative =
 			rs->ref.a.row_relative = rs->ref.b.row_relative = FALSE;
-	else if ((gee->flags & GNM_EE_FORCE_REL_REF))
+        else if ((gee->flags & GNM_EE_FORCE_REL_REF))
 		rs->ref.a.col_relative = rs->ref.b.col_relative =
 			rs->ref.a.row_relative = rs->ref.b.row_relative = TRUE;
 }
@@ -223,13 +226,13 @@ gee_rangesel_reset (GnmExprEntry *gee)
 
 	rs->text_start = 0;
 	rs->text_end = 0;
-	memset (&rs->ref, 0, sizeof (GnmRange));
+	memset (&rs->ref, 0, sizeof (rs->ref));
 	rs->ref.a.col_relative =
 	rs->ref.b.col_relative =
 	rs->ref.a.row_relative =
 	rs->ref.b.row_relative = ((gee->flags & (GNM_EE_FORCE_ABS_REF|GNM_EE_DEFAULT_ABS_REF)) == 0);
 
-	gee->rangesel.is_valid = FALSE;
+	rs->is_valid = FALSE;
 }
 
 static void
@@ -301,7 +304,7 @@ cb_icon_clicked (GtkButton *icon,
 				container_props = g_value_array_new (n);
 
 				for (ui = 0; ui < n; ui++) {
-					GValue value;
+					GValue value = G_VALUE_INIT;
 					g_value_init (&value, G_PARAM_SPEC_VALUE_TYPE (container_props_pspec[ui]));
 
 					gtk_container_child_get_property (GTK_CONTAINER (old_entry_parent), GTK_WIDGET (entry),
@@ -439,7 +442,8 @@ gee_set_format (GnmExprEntry *gee, GOFormat const *fmt)
 	gee->constant_format = fmt;
 
 	if (gee_debug)
-		g_printerr ("Setting format %s\n", fmt ? go_format_as_XL (fmt) : "-");
+		g_printerr ("Setting format %s\n",
+			    fmt ? go_format_as_XL (fmt) : "-");
 
 	if (fmt && go_format_is_date (fmt)) {
 		if (!gee->calendar_combo) {
@@ -592,29 +596,30 @@ gee_destroy_feedback_range (GnmExprEntry *gee)
 }
 
 static void
-gnm_expr_entry_colour_ranges (GnmExprEntry *gee, int start, int end, GnmRangeRef *rr, int colour)
+gnm_expr_entry_colour_ranges (GnmExprEntry *gee, int start, int end, GnmRangeRef *rr, int colour,
+			      PangoAttrList **attrs, gboolean insert_cursor)
 {
 	static struct {
 		guint16 red;
 		guint16 green;
 		guint16 blue;
 		gchar const *name;
-	} colours[] = {{0x0, 0x0, 0xFFFF, "00:00:ff:ff"},
-		       {0x0, 0xFFFF, 0x0, "00:ff:00:ff"},
-		       {0xFFFF, 0x0, 0x0, "ff:00:00:ff"}, 
-		       {0x0, 0x80FF, 0x80FF, "00:80:80:ff"}, 
-		       {0xA0FF, 0xA0FF, 0x0, "a0:a0:00:ff"}, 
+	} colours[] = {{0x0, 0xFFFF, 0x0, "00:ff:00:ff"},
+		       {0x0, 0x0, 0xFFFF, "00:00:ff:ff"},
+		       {0xFFFF, 0x0, 0x0, "ff:00:00:ff"},
+		       {0x0, 0x80FF, 0x80FF, "00:80:80:ff"},
+		       {0xA0FF, 0xA0FF, 0x0, "a0:a0:00:ff"},
 		       {0xA0FF, 0x0, 0xA0FF, "a0:00:a0:ff"}};
-	GtkEntry *entry = gee->entry;
-	PangoLayout *layout = gtk_entry_get_layout (entry);
 	PangoAttribute *at;
-	PangoAttrList *list = pango_layout_get_attributes (layout);
 	GnmRange r;
 	GnmRange const *merge; /*[#127415]*/
 	Sheet *start_sheet, *end_sheet;
 	Sheet *sheet = scg_sheet (gee->scg);
 	SheetControlGUI *scg = NULL;
 
+	if (*attrs == NULL)
+		*attrs = pango_attr_list_new ();
+
 	colour = colour % G_N_ELEMENTS (colours);
 
 	gnm_rangeref_normalize_pp (rr, &gee->pp,
@@ -623,24 +628,28 @@ gnm_expr_entry_colour_ranges (GnmExprEntry *gee, int start, int end, GnmRangeRef
 				   &r);
 	if (start_sheet != end_sheet)
 		return;
-	if (range_is_singleton  (&r) &&
-	    NULL != (merge = gnm_sheet_merge_is_corner
-		     (start_sheet, &r.start)))
-		r = *merge;
-	if (start_sheet == sheet) 
-		scg = gee->scg;
-	else {
-		WBCGtk *wbcg = scg_wbcg (gee->scg);
-		scg = wbcg_get_nth_scg (wbcg, start_sheet->index_in_wb);
-	}
-	
-	SCG_FOREACH_PANE (scg, pane, gnm_pane_expr_cursor_bound_set (pane, &r, colours[colour].name););
+	if (insert_cursor) {
+		if (range_is_singleton  (&r) &&
+		    NULL != (merge = gnm_sheet_merge_is_corner
+			     (start_sheet, &r.start)))
+			r = *merge;
+		if (start_sheet == sheet)
+			scg = gee->scg;
+		else {
+			WBCGtk *wbcg = scg_wbcg (gee->scg);
+			scg = wbcg_get_nth_scg (wbcg, start_sheet->index_in_wb);
+		}
 
-	at = pango_attr_foreground_new (colours[colour].red, colours[colour].green, colours[colour].blue);
-	at->start_index = gtk_entry_text_index_to_layout_index (entry, start);
-	at->end_index = gtk_entry_text_index_to_layout_index (entry, end);
-	
-	pango_attr_list_change (list, at);
+		SCG_FOREACH_PANE (scg, pane, gnm_pane_expr_cursor_bound_set
+				  (pane, &r, colours[colour].name););
+	}
+
+	at = pango_attr_foreground_new (colours[colour].red, colours[colour].green,
+					colours[colour].blue);
+	at->start_index = start;
+	at->end_index = end;
+
+	pango_attr_list_change (*attrs, at);
 }
 
 /* WARNING : DO NOT CALL THIS FROM FROM UPDATE.  It may create another
@@ -650,27 +659,58 @@ gnm_expr_entry_colour_ranges (GnmExprEntry *gee, int start, int end, GnmRangeRef
 static void
 gee_scan_for_range (GnmExprEntry *gee)
 {
+	PangoAttrList *attrs = NULL;
+
 	parse_pos_init_editpos (&gee->pp, scg_view (gee->scg));
 	gee_destroy_feedback_range (gee);
 	if (!gee->feedback_disabled && gee_is_editing (gee) && gee->lexer_items != NULL) {
 		GnmLexerItem *gli = gee->lexer_items;
-		int colour = 0;
+		int colour = 1; /* We start with 1 since GINT_TO_POINTER (0) == NULL */
+		GHashTable *hash = g_hash_table_new_full ((GHashFunc) gnm_rangeref_hash,
+							  (GEqualFunc) gnm_rangeref_equal,
+							  g_free,
+							  NULL);
 		do {
 			if (gli->token == RANGEREF) {
 				char const *text = gtk_entry_get_text (gee->entry);
-				char *rtext = g_strndup (text + gli->start, 
+				char *rtext = g_strndup (text + gli->start,
 							 gli->end - gli->start);
 				char const *tmp;
 				GnmRangeRef rr;
-				tmp = rangeref_parse (&rr, rtext, 
+				tmp = rangeref_parse (&rr, rtext,
 						      &gee->pp, gee_convs (gee));
-				if (tmp != rtext)
-					gnm_expr_entry_colour_ranges (gee, gli->start, gli->end, &rr, 
-								      colour++);
+				if (tmp != rtext) {
+					gpointer val;
+					gint this_colour;
+					gboolean insert_cursor;
+					if (rr.a.sheet == NULL)
+						rr.a.sheet = gee->sheet;
+					if (rr.b.sheet == NULL)
+						rr.b.sheet = rr.a.sheet;
+					val = g_hash_table_lookup (hash, &rr);
+					if (val == NULL) {
+						GnmRangeRef *rrr = gnm_rangeref_dup (&rr);
+						this_colour = colour++;
+						g_hash_table_insert (hash, rrr, GINT_TO_POINTER (this_colour));
+						insert_cursor = TRUE;
+						rtext = NULL;
+ 					} else {
+						this_colour = GPOINTER_TO_INT (val);
+						insert_cursor = FALSE;
+					}
+					gnm_expr_entry_colour_ranges (gee, gli->start, gli->end, &rr,
+								      this_colour, &attrs, insert_cursor);
+				}
 				g_free (rtext);
 			}
-		} while (gli++->token != 0);	
+		} while (gli++->token != 0);
+		g_hash_table_destroy (hash);
 	}
+	if (attrs)
+		g_object_set_data_full (G_OBJECT (gee->entry), "gnm:range-attributes", attrs,
+					(GDestroyNotify) pango_attr_list_unref);
+	else
+		g_object_set_data (G_OBJECT (gee->entry), "gnm:range-attributes", NULL);
 }
 
 static void
@@ -689,9 +729,16 @@ gee_update_env (GnmExprEntry *gee)
 
 }
 
-static void
+static gboolean
 gee_delete_tooltip (GnmExprEntry *gee, gboolean remove_completion)
 {
+	gboolean has_tooltip = (gee->tooltip.tooltip != NULL && 
+				gee->tooltip.timerid == 0);
+
+	if (gee->tooltip.timerid) {
+		g_source_remove (gee->tooltip.timerid);
+		gee->tooltip.timerid = 0;
+	}
 	if (gee->tooltip.tooltip) {
 		gtk_widget_destroy (gee->tooltip.tooltip);
 		gee->tooltip.tooltip = NULL;
@@ -711,6 +758,7 @@ gee_delete_tooltip (GnmExprEntry *gee, gboolean remove_completion)
 		gee->tooltip.completion = NULL;
 		gee->tooltip.completion_se_valid = FALSE;
 	}
+	return has_tooltip;
 }
 
 void
@@ -725,6 +773,16 @@ cb_gee_focus_out_event (GtkWidget         *widget,
 			GdkEventFocus     *event,
 			gpointer           user_data);
 
+static gboolean 
+cb_show_tooltip (gpointer user_data)
+{
+	GnmExprEntry *gee = GNM_EXPR_ENTRY (user_data);
+	gtk_widget_show_all (gee->tooltip.tooltip);
+	gee->tooltip.timerid = 0;
+	return FALSE;
+}
+
+
 static GtkWidget *
 gee_create_tooltip (GnmExprEntry *gee, gchar const *str,
 		    gchar const *marked_str, gboolean set_tabs)
@@ -735,6 +793,9 @@ gee_create_tooltip (GnmExprEntry *gee, gchar const *str,
 	GdkWindow *gdkw;
 	gchar *markup = NULL;
 	GString *string;
+	GtkTextBuffer *buffer;
+	PangoAttrList *attr_list = NULL;
+	char *text = NULL;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (gee->entry));
 	gtk_widget_add_events(toplevel, GDK_FOCUS_CHANGE_MASK);
@@ -743,7 +804,7 @@ gee_create_tooltip (GnmExprEntry *gee, gchar const *str,
 			(G_OBJECT (toplevel), "focus-out-event",
 			 G_CALLBACK (cb_gee_focus_out_event), gee);
 
-	label = gnumeric_create_tooltip (toplevel);
+	label = gnumeric_convert_to_tooltip (toplevel, gnumeric_create_tooltip_text_view_widget ());
 	tip = gtk_widget_get_toplevel (label);
 
 	if (str)
@@ -751,18 +812,31 @@ gee_create_tooltip (GnmExprEntry *gee, gchar const *str,
 	string = g_string_new (markup);
 	if (marked_str)
 		g_string_append (string, marked_str);
-	gtk_label_set_markup (GTK_LABEL (label), string->str);
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (label));
+
+	if (pango_parse_markup (string->str, -1, 0,
+				&attr_list, &text,
+				NULL, NULL)) {
+		gnm_create_std_tags_for_buffer (buffer);
+		gtk_text_buffer_set_text (buffer, text, -1);
+		gnm_load_pango_attributes_into_buffer (attr_list, buffer, text);
+		g_free (text);
+		pango_attr_list_unref (attr_list);
+	} else
+		gtk_text_buffer_set_text (buffer, string->str, -1);
 	g_free (markup);
 	g_string_free (string, TRUE);
 
 	if (set_tabs) {
-		PangoLayout *pl = gtk_label_get_layout (GTK_LABEL (label));
 		PangoTabArray *tabs;
 		tabs = pango_tab_array_new_with_positions
-			(2, TRUE,
-			 PANGO_TAB_LEFT, 120,
-			 PANGO_TAB_LEFT, 140);
-		pango_layout_set_tabs (pl, tabs);
+			(5, TRUE,
+			 PANGO_TAB_LEFT, 20,
+			 PANGO_TAB_LEFT, 140,
+			 PANGO_TAB_LEFT, 160,
+			 PANGO_TAB_LEFT, 180,
+			 PANGO_TAB_LEFT, 200);
+		gtk_text_view_set_tabs (GTK_TEXT_VIEW (label), tabs);
 		pango_tab_array_free (tabs);
 	}
 
@@ -774,8 +848,6 @@ gee_create_tooltip (GnmExprEntry *gee, gchar const *str,
 			 root_x + allocation.x,
 			 root_y + allocation.y + allocation.height);
 
-	gtk_widget_show_all (tip);
-
 	return tip;
 }
 
@@ -864,6 +936,7 @@ gee_set_tooltip (GnmExprEntry *gee, GnmFunc *fd, gint args, gboolean had_stuff)
 
 	gee->tooltip.tooltip = gee_create_tooltip
 		(gee, str->str, _("\n\n<i>Ctrl-F4 to close tooltip</i>"), FALSE);
+	gtk_widget_show_all (gee->tooltip.tooltip);
 	gee->tooltip.args = args;
 	gee->tooltip.had_stuff = (max == 0 && args == 0 && had_stuff);
 
@@ -879,10 +952,10 @@ gee_set_tooltip_completion (GnmExprEntry *gee, GSList *list, guint start, guint
 	gint max = 10;
 	GSList *list_c = list;
 	gchar const *name = NULL;
-	gboolean show_tool_tip;
+	gboolean show_tool_tip, had_tool_tip;
 	gboolean localized_function_names = gee->sheet->convs->localized_function_names;
 
-	gee_delete_tooltip (gee, TRUE);
+	had_tool_tip = gee_delete_tooltip (gee, TRUE);
 
 	str = g_string_new (NULL);
 	for (; list_c != NULL && ++i < max; list_c = list_c->next) {
@@ -891,12 +964,12 @@ gee_set_tooltip_completion (GnmExprEntry *gee, GSList *list, guint start, guint
 		if ((end - start) < (guint) g_utf8_strlen (name, -1))
 			/* xgettext: the first %s is a function name and */
 			/* the second %s the function description */
-			g_string_append_printf (str, _("%s : \t%s\n"), name,
+			g_string_append_printf (str, _("\t%s \t%s\n"), name,
 						gnm_func_get_description (fd));
 		else {
 			/* xgettext: the first %s is a function name and */
 			/* the second %s the function description */
-			g_string_append_printf (str, _("[%s : \t%s]\n"), name,
+			g_string_append_printf (str, _("\342\234\223\t%s \t%s\n"), name,
 						gnm_func_get_description (fd));
 			i--;
 		}
@@ -904,24 +977,33 @@ gee_set_tooltip_completion (GnmExprEntry *gee, GSList *list, guint start, guint
 
 	str_marked = g_string_new (NULL);
 	if (i == max)
-		g_string_append (str_marked, UNICODE_ELLIPSIS_VERT "\n");
+		g_string_append (str_marked, "\t" UNICODE_ELLIPSIS_VERT "\n");
 	if (i == 1) {
 		gee->tooltip.completion
 			= g_strdup (name);
 		/*xgettext: short form for: "type F4-key to complete the name"*/
-		g_string_append (str_marked, _("\n<i>F4 to complete</i>"));
+		g_string_append (str_marked, _("\n\t<i>F4 to complete</i>"));
 	} else if (i > 1)
 		/*xgettext: short form for: "type shift-F4-keys to select the completion"*/
-		g_string_append (str_marked, _("\n<i>\xe2\x87\xa7""F4 to select</i>"));
+		g_string_append (str_marked, _("\n\t<i>\xe2\x87\xa7""F4 to select</i>"));
 	else
 		g_string_truncate (str, str->len - 1);
 	gee->tooltip.completion_start = start;
 	gee->tooltip.completion_end = end;
 	gee->tooltip.completion_se_valid = TRUE;
 	show_tool_tip = gnm_conf_get_core_gui_editing_function_name_tooltips ();
-	if (show_tool_tip)
+	if (show_tool_tip) {
 		gee->tooltip.tooltip = gee_create_tooltip
 			(gee, str->str, str_marked->str, TRUE);
+		if (had_tool_tip)
+			gtk_widget_show_all (gee->tooltip.tooltip);
+		else
+			gee->tooltip.timerid = g_timeout_add_full 
+				(G_PRIORITY_DEFAULT, 750, 
+				 cb_show_tooltip, 
+				 gee, 
+				 NULL);
+	}
 	g_string_free (str, TRUE);
 	g_string_free (str_marked, TRUE);
 	g_slist_free_full (list, (GDestroyNotify) gnm_func_unref);
@@ -930,12 +1012,12 @@ gee_set_tooltip_completion (GnmExprEntry *gee, GSList *list, guint start, guint
 
 static void
 gee_dump_lexer (GnmLexerItem *gli) {
-	g_print ("************\n");
+	g_printerr ("************\n");
 	do {
-		g_print ("%2" G_GSIZE_FORMAT " to %2" G_GSIZE_FORMAT ": %d\n",
-			 gli->start, gli->end, gli->token);
+		g_printerr ("%2" G_GSIZE_FORMAT " to %2" G_GSIZE_FORMAT ": %d\n",
+			    gli->start, gli->end, gli->token);
 	} while (gli++->token != 0);
-	g_print ("************\n");
+	g_printerr ("************\n");
 
 }
 
@@ -1063,7 +1145,10 @@ gee_check_tooltip (GnmExprEntry *gee)
 		last_token = (gli - 1)->token;
 
 	/* This creates the completion tooltip */
-	if (!stuff && gli->token == STRING && last_token != CONSTANT) {
+	if (!stuff &&
+	    gli->token == STRING &&
+	    last_token != CONSTANT &&
+	    last_token != '$') {
 		guint start_t = gli->start;
 		char *prefix;
 		GSList *list;
@@ -1103,9 +1188,9 @@ gee_check_tooltip (GnmExprEntry *gee)
 		goto not_found;
 
 	if (gnm_debug_flag ("functooltip"))
-		g_print ("Last token considered is %d from %2"
-			 G_GSIZE_FORMAT " to %2" G_GSIZE_FORMAT ".\n",
-			 gli->token, gli->start, gli->end);
+		g_printerr ("Last token considered is %d from %2"
+			    G_GSIZE_FORMAT " to %2" G_GSIZE_FORMAT ".\n",
+			    gli->token, gli->start, gli->end);
 
 
 	while (gli->start > 1) {
@@ -1280,7 +1365,7 @@ cb_gee_key_press_event (GtkEntry	*entry,
 		/*        look it up rather than reparse */
 
 		/* Look for a range */
-		if (rs->text_start >= rs->text_end)
+		if (!rs->is_valid || rs->text_start >= rs->text_end)
 			gnm_expr_entry_find_range (gee);
 
 		/* no range found */
@@ -1855,15 +1940,12 @@ gnm_expr_entry_find_range (GnmExprEntry *gee)
 
 	g_return_val_if_fail (gee != NULL, FALSE);
 
-	rs     = &gee->rangesel;
 	single = (gee->flags & GNM_EE_SINGLE_RANGE) != 0;
-
-
-	rs->ref.a.sheet = rs->ref.b.sheet = NULL;
+	rs = &gee->rangesel;
+	memset (rs, 0, sizeof (*rs));
+	rs->ref.a.col_relative = rs->ref.a.row_relative = TRUE;
+	rs->ref.b.col_relative = rs->ref.b.row_relative = TRUE;
 	gee_force_abs_rel (gee);
-	rs->is_valid = FALSE;
-	rs->text_start = 0;
-	rs->text_end = 0;
 
 	text = gtk_entry_get_text (gee->entry);
 	if (text == NULL)
@@ -1876,6 +1958,7 @@ gnm_expr_entry_find_range (GnmExprEntry *gee)
 	len = g_utf8_strlen (text, -1);
 
 	if (single) {
+		GnmRangeRef range;
 		rs->text_start = 0;
 		rs->text_end = len;
 		tmp = rangeref_parse (&range, text, &gee->pp, gee_convs (gee));
@@ -1914,7 +1997,7 @@ gnm_expr_entry_find_range (GnmExprEntry *gee)
 	if (gli->token == 0) {
 		rs->text_start = g_utf8_pointer_to_offset
 			(text, ptr);
-		rs->text_end   = len;
+		rs->text_end = len;
 		return TRUE;
 	}
 
@@ -1923,11 +2006,11 @@ gnm_expr_entry_find_range (GnmExprEntry *gee)
 	gee_find_lexer_token (gli, (guint)token_pos, &gli_before, &gli_after);
 
 	if (gnm_debug_flag ("rangeselection")) {
-		g_print ("before: %p -- after: %p\n", gli_before, gli_after);
+		g_printerr ("before: %p -- after: %p\n", gli_before, gli_after);
 		if (gli_before)
-			g_print ("before token: %d\n", gli_before->token);
+			g_printerr ("before token: %d\n", gli_before->token);
 		if (gli_after)
-			g_print ("after token: %d\n", gli_after->token);
+			g_printerr ("after token: %d\n", gli_after->token);
 	}
 
 	if (gli_before == NULL && gli_after == NULL)
@@ -2027,8 +2110,8 @@ gnm_expr_entry_find_range (GnmExprEntry *gee)
 		}
 
 	if (gnm_debug_flag ("rangeselection"))
-		g_print ("characters from %d to %d\n",
-			 rs->text_start, rs->text_end);
+		g_printerr ("characters from %d to %d\n",
+			    rs->text_start, rs->text_end);
 
 	rs_text = gtk_editable_get_chars (GTK_EDITABLE (gee->entry),
 					  rs->text_start, rs->text_end);
@@ -2236,10 +2319,15 @@ gnm_expr_entry_set_flags (GnmExprEntry *gee,
 			  GnmExprEntryFlags flags,
 			  GnmExprEntryFlags mask)
 {
+	GnmExprEntryFlags newflags;
 	g_return_if_fail (IS_GNM_EXPR_ENTRY (gee));
 
-	gee->flags = (gee->flags & ~mask) | (flags & mask);
-	gee_force_abs_rel (gee);
+	newflags = (gee->flags & ~mask) | (flags & mask);
+	if (gee->flags == newflags)
+		return;
+
+	gee->flags = newflags;
+	gee_rangesel_reset (gee);
 }
 
 /**
@@ -2266,7 +2354,7 @@ gnm_expr_entry_set_scg (GnmExprEntry *gee, SheetControlGUI *scg)
 		g_object_weak_ref (G_OBJECT (gee->scg),
 				   (GWeakNotify) cb_scg_destroy, gee);
 		gee->sheet = sc_sheet (SHEET_CONTROL (scg));
-		parse_pos_init_sheet (&gee->pp, gee->sheet);
+		parse_pos_init_editpos (&gee->pp, scg_view (gee->scg));
 		gee->wbcg = scg_wbcg (gee->scg);
 	} else
 		gee->sheet = NULL;
