@@ -7,8 +7,9 @@
  * Copyright (C) 2003-2007 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -82,9 +83,9 @@ typedef struct {
 void
 gnm_xml_out_add_gocolor (GsfXMLOut *o, char const *id, GOColor c)
 {
-	GdkRGBA tmp;
-	go_color_to_gdk_rgba (c, &tmp);
-	gsf_xml_out_add_color (o, id, tmp.red * 65535, tmp.green * 65535, tmp.blue * 65535);
+	unsigned r, g, b, a;
+	GO_COLOR_TO_RGBA (c, &r, &g, &b, &a);
+	gsf_xml_out_add_color (o, id, r * 0x101, g * 0x101, b * 0x101);
 }
 
 static void
@@ -710,12 +711,15 @@ xml_write_colrow_info (GnmColRowIter const *iter, closure_write_colrow *closure)
 {
 	ColRowInfo const *prev = closure->prev;
 	GsfXMLOut *output = closure->state->output;
+	ColRowInfo const *def =
+		sheet_colrow_get_default (closure->state->sheet,
+					  closure->is_column);
 
 	closure->rle_count++;
 	if (NULL != iter && colrow_equal (prev, iter->cri))
 		return FALSE;
 
-	if (prev != NULL) {
+	if (prev != NULL && !colrow_equal (prev, def)) {
 		if (closure->is_column)
 			gsf_xml_out_start_element (output, GNM "ColInfo");
 		else
